==> catseye-fm-3.0.0.0.tar.gz: catseye-fm-3.0.0.0/internals.c <==
/*
    Copyright 2007, 2008, 2009 Geyer Klaus

    This file is part of Cat'sEyE.

    Cat'sEyE is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Cat'sEyE is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Cat'sEyE.  If not, see <http://www.gnu.org/licenses/>.
*/



#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>

#include <sys/types.h>
#include <sys/stat.h>

#include "confighandling.h"
#include "globalDefinitions.h"
#include "helpers.h"
#include "internals.h"
//#include "Lists.h"
//#include "myfm.h"
#include "mytrace.h"



#define ABOUTTEXT "\n\n    Copyright 2007, 2008, 2009 Geyer Klaus\n\
\n\
    Cat'sEyE is free software: you can redistribute it and/or modify\n\
    it under the terms of the GNU General Public License as published by    \n\
    the Free Software Foundation, either version 3 of the License, or\n\
    (at your option) any later version.\n\
\n\
    Cat'sEyE is distributed in the hope that it will be useful,\n\
    but WITHOUT ANY WARRANTY; without even the implied warranty of\n\
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n\
    GNU General Public License for more details.\n\
\n\
    You should have received a copy of the GNU General Public License\n\
    along with Cat'sEyE.  If not, see <http://www.gnu.org/licenses/>.\n\n"



#define NEWUSERCOMMANDINFORATION "\n\nThis is a summary of the keywords of the newusercommand\n\
\n\
    <command text=\"\" />\n\
    <dialog caption=\"\" label=\"\" question=\"\"<VAR1>predefine=\"\" question=\"\"<VAR2>predefine=<> />\n\
    <options call=\"all|each|list\" caption=\"\" label=\"\" quitreply=\"<VAR1>\" folderupdate=\"<Home>\" actionnote=\"label\" />\n\
\n\
    predefined variables:\n\
        <ThisDirectory> <TDIR>    <OtherDirectory> <ODIR>\n\
        <MarkedItems> <MI>    <MarkedItemsUnQuoted> <MI_UQ>\n\
        <MarkedItemsWithPath> <MIWP>    <MarkedItemsWithPathUnQuoted> <MIWP_UQ>\n\
        <Home> <home>\n\
"


extern GtkWindow 	*win;
extern GtkTextBuffer *g_TextBuffer_CommandHistory;

void internalMenuAbout(){
	TRACEIT(10,"internalMenuAbout		start");
	GtkWidget *dialog, *label1, *label2, *sep;
	GString *lbl1=g_string_sized_new(20);
	sep = gtk_hseparator_new ();
	dialog = CreateMyDialog("About", NULL, 1, "close", GTK_RESPONSE_ACCEPT, NULL, 0, FALSE);
	AddMyIconsToWindow((GtkWindow *)dialog);

    #ifdef ITTRACE
	g_string_printf(lbl1,"\nThis is %s, a filebrowser using the GTK.\n\
        \nVersion: %s , %d\tbuild: %s,%s\n\nTracelevel is set to %d, to change this\
        \nrebuild with '-D ITTRACE=<Num>' \nwhere <Num> is the tracelevel you want.\n\
        \nGTK version linked to: %d.%d.%d\
        \nGTK version of headers used to compile: %d.%d.%d\n\
        \nglib version linked to: %d.%d.%d\
        \nglib version of headers used to compile: %d.%d.%d\n",
        MYNAME,VERSION, INTERNALBUILDNUMBER, __DATE__,__TIME__,ITTRACE,
        gtk_major_version,gtk_minor_version,gtk_micro_version,
        GTK_MAJOR_VERSION,GTK_MINOR_VERSION,GTK_MICRO_VERSION,
        glib_major_version,glib_minor_version,glib_micro_version,
        GLIB_MAJOR_VERSION,GLIB_MINOR_VERSION,GLIB_MICRO_VERSION);
	#else
    g_string_printf(lbl1,"\nThis is %s, a filebrowser using the GTK.\n\
        \nVersion: %s , %d\tbuild: %s,%s\n\nTracelevel is set to %d, to change this\
        \nrebuild with '-D ITTRACE=<Num>' \nwhere <Num> is the tracelevel you want.\n\
        \nGTK version linked to: %d.%d.%d\
        \nGTK version of headers used to compile: %d.%d.%d\n\
        \nglib version linked to: %d.%d.%d\
        \nglib version of headers used to compile: %d.%d.%d\n",
        MYNAME,VERSION, INTERNALBUILDNUMBER, __DATE__,__TIME__,0,
        gtk_major_version,gtk_minor_version,gtk_micro_version,
        GTK_MAJOR_VERSION,GTK_MINOR_VERSION,GTK_MICRO_VERSION,
        glib_major_version,glib_minor_version,glib_micro_version,
        GLIB_MAJOR_VERSION,GLIB_MINOR_VERSION,GLIB_MICRO_VERSION);
    #endif

	label1 = gtk_label_new(lbl1->str);
	label2 = gtk_label_new(ABOUTTEXT);

	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox),label1);
	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox),sep);
	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox),label2);
	gtk_widget_show_all(dialog);
	gtk_dialog_run(GTK_DIALOG(dialog));

	gtk_widget_destroy(dialog);
	g_string_free(lbl1,TRUE);
	TRACEIT(10,"internalMenuAbout		end");
}


void internalMenuCreateConfigFile(){
    TRACEIT(10,"internalMenuCreateConfigFile		start");
    GtkWidget *dialog, *label1;
    GString *gstr_labelText=NULL;
    GString *gstrHomeDir = NULL;
    GDir *gdirHomeDir=NULL;
    FILE *confFile=NULL;

    gstr_labelText = g_string_new("This will create a hidden directory named .catseye and a\nempty configfile where you can define Cat\'sEyEs behaviour\nin your homedirectory\n\n Press Ok to proceed.\n");

    dialog = CreateMyDialog("Create config file", NULL, 2, "Ok", GTK_RESPONSE_ACCEPT, "Cancel", GTK_RESPONSE_REJECT , FALSE);
    AddMyIconsToWindow((GtkWindow *)dialog);
    label1 = gtk_label_new(gstr_labelText->str);
    gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox),label1);
    gtk_widget_show_all(dialog);
    if (gtk_dialog_run(GTK_DIALOG(dialog))== GTK_RESPONSE_ACCEPT){
        gtk_widget_destroy(dialog);
        getHomeDirectory(&gstrHomeDir);
        checkPathForLastChar(gstrHomeDir);
        g_string_append(gstrHomeDir,CATSEYEHOMEDIR);
        gdirHomeDir = g_dir_open (gstrHomeDir->str, 0, NULL);
        if (gdirHomeDir==NULL){
            g_string_prepend(gstrHomeDir,"mkdir ");
            //g_spawn_command_line_sync (gstrHomeDir->str,NULL,NULL,NULL,NULL);
            myWrapOf__g_spawn_command_line_sync (gstrHomeDir->str,NULL,NULL,NULL,NULL);

            getHomeDirectory(&gstrHomeDir);
            checkPathForLastChar(gstrHomeDir);
            g_string_append(gstrHomeDir,CATSEYEHOMEDIR);

            gdirHomeDir = g_dir_open (gstrHomeDir->str, 0, NULL);
            if (gdirHomeDir==NULL){
                MyMessageWidget(NULL, "Error", "Error creating .catseye in \nyour homedirectory\n");
                g_string_free(gstr_labelText,TRUE);
                g_string_free(gstrHomeDir,TRUE);
                TRACEIT(10,"internalMenuCreateConfigFile		end");
                return;
            }
            g_dir_close(gdirHomeDir);
        }
        else{
            g_dir_close(gdirHomeDir);
        }

        getHomeDirectory(&gstrHomeDir);
        checkPathForLastChar(gstrHomeDir);
        g_string_append(gstrHomeDir,CONFIG_FILE_TYPES);
        confFile = fopen (gstrHomeDir->str,"r");
        if (confFile != NULL){
            MyMessageWidget(NULL, "Error", "config file already exists\n\n");
            fclose(confFile);
            g_string_free(gstr_labelText,TRUE);
            g_string_free(gstrHomeDir,TRUE);
            TRACEIT(10,"internalMenuCreateConfigFile		end");
            return;
        }
        confFile = fopen(gstrHomeDir->str,"w+");
        if (confFile == NULL){
            MyMessageWidget(NULL, "Error", "Error creating config file\n\n");
            g_string_free(gstr_labelText,TRUE);
            g_string_free(gstrHomeDir,TRUE);
            TRACEIT(10,"internalMenuCreateConfigFile		end");
            return;
        }

        fprintf(confFile,"%s\n%s\n\n","PROGRAMSEPERATOR",PROGRAMSEPERATOR);

        fprintf(confFile,"%s\n#%s%s#000000\n\n","COLOR_ITEMS_DEFAULT, one single",COLOR_ITEMS_DEFAULT,TYPESEPARATOR);
        fprintf(confFile,"%s\n#%s%sBlue\n\n","COLOR_DIRECTORIES, one single",COLOR_DIRECTORIES,TYPESEPARATOR);
        fprintf(confFile,"%s\n#%s%sCornflowerBlue\n\n","COLOR_LINKS, one single",COLOR_LINKS,TYPESEPARATOR);
        fprintf(confFile,"%s\n#%s%sRed\n\n","COLOR_ITEMS_MISSING, one single",COLOR_ITEMS_MISSING,TYPESEPARATOR);

        fprintf(confFile,"%s\n%s%s\n\n","STANDARDEDITORKEY, one pair",STANDARDEDITORKEY,TYPESEPARATOR);
        fprintf(confFile,"%s\n%s%sxterm%sxterm\n\n","TERMINALKEY, one pair",TERMINALKEY,TYPESEPARATOR,PROGRAMSEPERATOR);
        fprintf(confFile,"%s\n%s%s\n\n","STANDARDSTARTDIRECTORY, one single",STANDARDSTARTDIRECTORY,TYPESEPARATOR);
        fprintf(confFile,"%s\n%s%sTRUE\n\n","SAVEPATHESONEXIT, TRUE or FALSE",SAVEPATHESONEXIT,TYPESEPARATOR);
        fprintf(confFile,"%s\n%s%s\n\n","STARTDIRECTORIESLEFTKEY, singles",STARTDIRECTORIESLEFTKEY,TYPESEPARATOR);
        fprintf(confFile,"%s\n%s%s\n\n","STARTDIRECTORIESRIGHTKEY, singles",STARTDIRECTORIESRIGHTKEY,TYPESEPARATOR);
        fprintf(confFile,"%s\n%s%s\n\n","BOOKMARKS, pairs",BOOKMARKS,TYPESEPARATOR);
        fprintf(confFile,"%s\n%s%s\n\n","COUNTSFORALLITEMSKEY, pairs",COUNTSFORALLITEMSKEY,TYPESEPARATOR);

        fputs(NEWUSERCOMMANDINFORATION,confFile);

        fclose(confFile);

        MyMessageWidget(NULL, "Finished", "Directory and config file successfully created\n\n");
    }

    gtk_widget_destroy(dialog);
    g_string_free(gstr_labelText,TRUE);
    if (gstrHomeDir)
        g_string_free(gstrHomeDir,TRUE);

    TRACEIT(10,"internalMenuCreateConfigFile		end");
}


void internalSavePatheAsBookmark(char *Path){
    TRACEIT(10,"internalSavePatheAsBookmark		start");
    if (Path == NULL){
        return;
    }

    GString *gstrBuf = g_string_sized_new(10);
    char text[] = "This will add the current path\nas bookmark to your configuration file.\nPlease enter a name:\n";
    struct myFiles_struct *filestru=NULL;

    g_string_assign(gstrBuf,Path);
    getLastStringInPath(gstrBuf);

    if (0== MyEasyInputWidget (win, "Add bookmark", text, gstrBuf)){
        filestru = myFiles_openConfigTypesFile("a");
        if (filestru == NULL){
            MyMessageWidget(win, "Error", "Cant open configfile.\nMake sure the file exists and is writeable.\nYou may let Cat'sEyE create it for you,\nsee other menuitem.\n" );
            TRACEIT(10,"myFiles_ConfigFileSimpleGetValue		ends, error opening configfile");
            g_string_free(gstrBuf, TRUE);
            return;
        }
        g_string_append(gstrBuf, PROGRAMSEPERATOR);
        g_string_append(gstrBuf, Path);
        g_string_append(gstrBuf, "\n");
        g_string_prepend(gstrBuf, TYPESEPARATOR);
        g_string_prepend(gstrBuf, BOOKMARKS);
        if (0 != myFiles_SaveValueToFile(filestru, gstrBuf->str)){
            MyMessageWidget(win, "Error", "Cant write to configfile.\nMake sure the file exists and is writeable.\n" );
            TRACEIT(10,"internalSavePatheAsBookmark		ends, error writing configfile");
        }
        myFiles_closeFile(filestru);
    }
    g_string_free(gstrBuf, TRUE);
    TRACEIT(10,"internalSavePatheAsBookmark		ends");
    return;
}


void internalMenuCommandHistory_ShowTextThread (void *data){
    TRACEIT(10,"internalMenuCommandHistory_ShowTextThread		start");
    gdk_threads_enter();
    GtkWidget *label;
    GtkVBox *VBox;
    GtkWidget *TextView = gtk_text_view_new_with_buffer (g_TextBuffer_CommandHistory);
    VBox = g_object_new(GTK_TYPE_VBOX, "spacing", 5, "homogeneous", FALSE, NULL);
    GtkWidget *scrollwidget;

    label = gtk_label_new("This is the history of all commands Cat'sEyE sent to the shell.\nThis includes copy, move, remove, rename and user commands.");
    gtk_misc_set_alignment ( (GtkMisc *)label, 0.0f, 0.0f);
    gtk_misc_set_padding ( (GtkMisc *)label, 4, 0);
    gtk_label_set_line_wrap ((GtkLabel *)label, TRUE);

    scrollwidget = gtk_scrolled_window_new(NULL,NULL);

    GtkWidget *dialog = CreateMyWindow("Command history", win, 400, 300, TRUE, TRUE, FALSE, NULL, FALSE );
    AddMyIconsToWindow((GtkWindow *)dialog);

    gtk_scrolled_window_add_with_viewport ( (GtkScrolledWindow *)scrollwidget, TextView);
    gtk_container_add((GtkContainer *)VBox,(GtkWidget *)label);
    gtk_box_set_child_packing ((GtkBox *)VBox, (GtkWidget *)label, FALSE, TRUE, 4, GTK_PACK_START);
    gtk_container_add(GTK_CONTAINER(VBox),scrollwidget);
    gtk_container_add((GtkContainer *)dialog,(GtkWidget *)VBox);

	gtk_widget_show_all(dialog);

	gdk_threads_leave();

	TRACEIT(10,"internalMenuCommandHistory_ShowTextThread		ends");
	g_thread_exit(0);
}


void internalMenuCommandHistory (){
    TRACEIT(10,"internalMenuCommandHistory		start");
    if (g_TextBuffer_CommandHistory == NULL)
        return;

    if( !g_thread_supported() ){
		g_thread_init(NULL);
     		//gdk_threads_init();                   // Called to initialize internal mutex "gdk_threads_mutex".
	}
    g_thread_create((GThreadFunc)internalMenuCommandHistory_ShowTextThread, NULL , FALSE, NULL);
    TRACEIT(10,"internalMenuCommandHistory		ends");
    return;
}

==> catseye-fm-4.2.0.0.tar.gz: catseye-fm-4.2.0.0/internals.c <==
/*
    Copyright 2007, 2008, 2009, 2010 Geyer Klaus

    This file is part of Cat'sEyE.

    Cat'sEyE is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Cat'sEyE is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Cat'sEyE.  If not, see <http://www.gnu.org/licenses/>.
*/



#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>

#include <sys/types.h>
#include <sys/stat.h>

#include "confighandling.h"
#include "confighandlingDefinitions.h"
#include "globalDefinitions.h"
#include "helpers.h"
#include "internals.h"
#include "mytrace.h"

#include "allInclude.h"

#define ABOUTTEXT "\n\n    Copyright 2007, 2008, 2009, 2010 Geyer Klaus\n\
\n\
    Cat'sEyE is free software: you can redistribute it and/or modify\n\
    it under the terms of the GNU General Public License as published by    \n\
    the Free Software Foundation, either version 3 of the License, or\n\
    (at your option) any later version.\n\
\n\
    Cat'sEyE is distributed in the hope that it will be useful,\n\
    but WITHOUT ANY WARRANTY; without even the implied warranty of\n\
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n\
    GNU General Public License for more details.\n\
\n\
    You should have received a copy of the GNU General Public License\n\
    along with Cat'sEyE.  If not, see <http://www.gnu.org/licenses/>.\n\n"


extern GtkWindow 	*win;
extern GtkTextBuffer *g_TextBuffer_CommandHistory;

void internalMenuAbout(){
	TRACEIT(10,"internalMenuAbout		start");
	GtkWidget *dialog, *label1, *label2, *sep;
	GString *lbl1=g_string_sized_new(20);
	GString *gstrBuf=g_string_sized_new(20);
	sep = gtk_hseparator_new ();
	dialog = CreateMyDialog("About", NULL, 1, "close", GTK_RESPONSE_ACCEPT, NULL, 0, NULL, 0, FALSE);
	AddMyIconsToWindow((GtkWindow *)dialog);


    g_string_printf(lbl1,"\nThis is %s, a filebrowser using the GTK.\n\
        \nVersion: %s , %d\tbuild: %s,%s\n\n",MYNAME,VERSION, INTERNALBUILDNUMBER, __DATE__,__TIME__);

    g_string_printf(gstrBuf,"Tracelevel is set to %d, to change this\
        \nrebuild with '-D ITTRACE=<Num>' \nwhere <Num> is the tracelevel you want.\n",
    #ifdef ITTRACEinternalMenuCommandHistory_ShowTextThread
        ITTRACE);
    #else
        0);
    #endif
    g_string_append(lbl1, gstrBuf->str);

    #ifdef NO_GIO
    g_string_printf(gstrBuf, "NO_GIO option was enabled at compile time, no function\n\
        from the gio framework is used. Please mind, that the user has to update the \n\
        views manually and the copy- move- and remove-functions\n\
        are those used with the shell.\n");
    g_string_append(lbl1, gstrBuf->str);
    #endif

    g_string_printf(gstrBuf,"\nGTK version linked to: %d.%d.%d\
        \nGTK version of headers used to compile: %d.%d.%d\n\
        \nglib version linked to: %d.%d.%d\
        \nglib version of headers used to compile: %d.%d.%d\n",
        gtk_major_version,gtk_minor_version,gtk_micro_version,
        GTK_MAJOR_VERSION,GTK_MINOR_VERSION,GTK_MICRO_VERSION,
        glib_major_version,glib_minor_version,glib_micro_version,
        GLIB_MAJOR_VERSION,GLIB_MINOR_VERSION,GLIB_MICRO_VERSION);
    g_string_append(lbl1, gstrBuf->str);


	label1 = gtk_label_new(lbl1->str);
	label2 = gtk_label_new(ABOUTTEXT);

	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox),label1);
	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox),sep);
	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox),label2);
	gtk_widget_show_all(dialog);
	gtk_dialog_run(GTK_DIALOG(dialog));

	gtk_widget_destroy(dialog);
	g_string_free(lbl1,TRUE);
	g_string_free(gstrBuf, TRUE);
	TRACEIT(10,"internalMenuAbout		end");
}


void internalMenuCommandHistory_ShowTextThread (void *data){
    TRACEIT(10,"internalMenuCommandHistory_ShowTextThread		start");
    //myWrap_gdk_threads_enter("internalMenuCommandHistory_ShowTextThread");
    GtkWidget *label;
    GtkVBox *VBox;
    GtkWidget *TextView = gtk_text_view_new_with_buffer (g_TextBuffer_CommandHistory);
    VBox = g_object_new(GTK_TYPE_VBOX, "spacing", 5, "homogeneous", FALSE, NULL);
    GtkWidget *scrollwidget;

    label = gtk_label_new("This is the history of all commands Cat'sEyE sent to the shell.\nThis includes copy, move, remove, rename and user commands.");
    gtk_misc_set_alignment ( (GtkMisc *)label, 0.0f, 0.0f);
    gtk_misc_set_padding ( (GtkMisc *)label, 4, 0);
    gtk_label_set_line_wrap ((GtkLabel *)label, TRUE);

    scrollwidget = gtk_scrolled_window_new(NULL,NULL);

    GtkWidget *dialog = CreateMyWindow("Command history", win, 400, 300, TRUE, TRUE, FALSE, NULL, FALSE, TRUE );
    AddMyIconsToWindow((GtkWindow *)dialog);

    gtk_scrolled_window_add_with_viewport ( (GtkScrolledWindow *)scrollwidget, TextView);
    gtk_container_add((GtkContainer *)VBox,(GtkWidget *)label);
    gtk_box_set_child_packing ((GtkBox *)VBox, (GtkWidget *)label, FALSE, TRUE, 4, GTK_PACK_START);
    gtk_container_add(GTK_CONTAINER(VBox),scrollwidget);
    gtk_container_add((GtkContainer *)dialog,(GtkWidget *)VBox);

	gtk_widget_show_all(dialog);

	//myWrap_gdk_threads_leave("internalMenuCommandHistory_ShowTextThread");

	TRACEIT(10,"internalMenuCommandHistory_ShowTextThread		ends");
	//g_thread_exit(0);
}


void internalMenuCommandHistory (){
    TRACEIT(10,"internalMenuCommandHistory		start");
    if (g_TextBuffer_CommandHistory == NULL)
        return;

    //if( !g_thread_supported() ){
	//	g_thread_init(NULL);
     		//gdk_threads_init();                   // Called to initialize internal mutex "gdk_threads_mutex".
	//}
    //g_thread_create((GThreadFunc)internalMenuCommandHistory_ShowTextThread, NULL , FALSE, NULL);
    internalMenuCommandHistory_ShowTextThread (NULL);
    TRACEIT(10,"internalMenuCommandHistory		ends");
    return;
}
